# mypy-boto3-frauddetector

[![PyPI - mypy-boto3-frauddetector](https://img.shields.io/pypi/v/mypy-boto3-frauddetector.svg?color=blue)](https://pypi.org/project/mypy-boto3-frauddetector)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-frauddetector.svg?color=blue)](https://pypi.org/project/mypy-boto3-frauddetector)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.FraudDetector 1.15.4](https://boto3.amazonaws.com/v1/documentation/api/1.15.4/reference/services/frauddetector.html#FraudDetector) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.1.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-frauddetector](#mypy-boto3-frauddetector)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `FraudDetector` service.

```bash
python -m pip install boto3-stubs[frauddetector]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[frauddetector]` in your environment: `python -m pip install 'boto3-stubs[frauddetector]'`

Both type checking and auto-complete should work for `FraudDetector` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[frauddetector]` in your environment: `python -m pip install 'boto3-stubs[frauddetector]'`

Both type checking and auto-complete should work for `FraudDetector` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[frauddetector]` in your environment: `python -m pip install 'boto3-stubs[frauddetector]'`
- Run `mypy` as usual

Type checking should work for `FraudDetector` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[frauddetector]` in your environment: `python -m pip install 'boto3-stubs[frauddetector]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `FraudDetector` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`FraudDetectorClient` provides annotations for `boto3.client("frauddetector")`.

```python
import boto3

from mypy_boto3_frauddetector import FraudDetectorClient

client: FraudDetectorClient = boto3.client("frauddetector")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: FraudDetectorClient = session.client("frauddetector")
```








### Typed dictionations

`mypy_boto3_frauddetector.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_frauddetector.type_defs import (
    BatchCreateVariableErrorTypeDef,
    BatchCreateVariableResultTypeDef,
    BatchGetVariableErrorTypeDef,
    BatchGetVariableResultTypeDef,
    CreateDetectorVersionResultTypeDef,
    CreateModelVersionResultTypeDef,
    CreateRuleResultTypeDef,
    DataValidationMetricsTypeDef,
    DescribeDetectorResultTypeDef,
    DescribeModelVersionsResultTypeDef,
    DetectorTypeDef,
    DetectorVersionSummaryTypeDef,
    EntityTypeDef,
    EntityTypeTypeDef,
    EventTypeTypeDef,
    ExternalEventsDetailTypeDef,
    ExternalModelTypeDef,
    FieldValidationMessageTypeDef,
    FileValidationMessageTypeDef,
    GetDetectorsResultTypeDef,
    GetDetectorVersionResultTypeDef,
    GetEntityTypesResultTypeDef,
    GetEventPredictionResultTypeDef,
    GetEventTypesResultTypeDef,
    GetExternalModelsResultTypeDef,
    GetKMSEncryptionKeyResultTypeDef,
    GetLabelsResultTypeDef,
    GetModelsResultTypeDef,
    GetModelVersionResultTypeDef,
    GetOutcomesResultTypeDef,
    GetRulesResultTypeDef,
    GetVariablesResultTypeDef,
    KMSKeyTypeDef,
    LabelSchemaTypeDef,
    LabelTypeDef,
    ListTagsForResourceResultTypeDef,
    MetricDataPointTypeDef,
    ModelEndpointDataBlobTypeDef,
    ModelInputConfigurationTypeDef,
    ModelOutputConfigurationTypeDef,
    ModelScoresTypeDef,
    ModelTypeDef,
    ModelVersionDetailTypeDef,
    ModelVersionTypeDef,
    OutcomeTypeDef,
    RuleDetailTypeDef,
    RuleResultTypeDef,
    RuleTypeDef,
    TagTypeDef,
    TrainingDataSchemaTypeDef,
    TrainingMetricsTypeDef,
    TrainingResultTypeDef,
    UpdateModelVersionResultTypeDef,
    UpdateRuleVersionResultTypeDef,
    VariableEntryTypeDef,
    VariableTypeDef,
)

def get_structure() -> BatchCreateVariableErrorTypeDef:
    return {
      ...
    }
```
